import raspberry_case
from solid import *
from solid.utils import *  # Not required, but the utils module is useful

import robothead_mount

SEGMENTS = 100

BASE_Y_LEN=58
PLATE_WIDTH=2
FRONT_X_SHIFT=25
BACK_X_SHIFT=15
BASE_X_LEN=65
SUPPORT_X_LEN=BASE_X_LEN - FRONT_X_SHIFT - BACK_X_SHIFT

REINFORCE_WIDTH=5

RASP_PLATE_HEIGHT=28
RASP_PLATE_X_SHIFT=20

SERVO_HEAD_DIAMETER = 24.5 # 24.5
SERVO_HEAD_DIAMETER_MARGIN = 3.5
HOLE_FRONT_X_SHIFT=16.5
HOLE_FRONT_Y_SHIFT=10
HOLE_BACK_X_SHIFT=32.5
HOLE_BACK_Y_SHIFT=10
HOLE_RADIUS=1.75
RASP_HOLE_X_SHIFT=40
RASP_HOLE_Y_SHIFT=15
RASP_HOLE_RADIUS=1.75


def parallelogram(w,h, skew, plate_width):
  return linear_extrude(height = plate_width)(
      polygon(points=[[0,0], [w,0], [w + skew, h], [skew,h], [0,0]], paths=[[0,1,2,3]])
  )


def y_symetry(obj):
  return scale([1,-1,1])(obj)

RASP_FIX_PLATE_WIDTH=3

def head_mount():
  base = left(FRONT_X_SHIFT)(forward(-BASE_Y_LEN / 2.0)
                             (cube([BASE_X_LEN, BASE_Y_LEN, PLATE_WIDTH])))

  p = parallelogram(SUPPORT_X_LEN,
                    RASP_PLATE_HEIGHT,
                    RASP_PLATE_X_SHIFT,
                    PLATE_WIDTH)
  p = rotate([90,0,0]) (p)
  
  rear_reinforce_l = back(BASE_Y_LEN / 2.0) (p)

  p2 = parallelogram(SUPPORT_X_LEN,
                     RASP_PLATE_HEIGHT / 4.0,
                     RASP_PLATE_X_SHIFT / 4.0,
                     BASE_Y_LEN)
  p2 = rotate([90,0,0]) (p2)
  rear_reinforce_base = p2
  rear_reinforce_base = forward(BASE_Y_LEN / 2.0)(rear_reinforce_base)

  p3 = parallelogram(SUPPORT_X_LEN,
                     RASP_PLATE_HEIGHT / 3.9,
                     RASP_PLATE_X_SHIFT / 3.9,
                     BASE_Y_LEN - REINFORCE_WIDTH * 2.0)
  p3 = rotate([90,0,0])(p3)
  rear_reinforce_base -= forward(BASE_Y_LEN / 2.0 - REINFORCE_WIDTH)(left(REINFORCE_WIDTH)(p3))
    
  rear_reinforce = rear_reinforce_l + y_symetry(rear_reinforce_l)

  rear_reinforce = right(BACK_X_SHIFT)(rear_reinforce + rear_reinforce_base)

  rasp_plate = right(BACK_X_SHIFT + RASP_PLATE_X_SHIFT)(forward(-BASE_Y_LEN / 2.0 - PLATE_WIDTH)
                                   (cube([SUPPORT_X_LEN, BASE_Y_LEN + 2 * PLATE_WIDTH, PLATE_WIDTH])))

  rasp_plate = up(RASP_PLATE_HEIGHT)(rasp_plate)

  

#  rasp_plate = up(PLATE_WIDTH)
  

  servo_hole = translate([0,0, 5]) (
    cylinder(r = (SERVO_HEAD_DIAMETER + SERVO_HEAD_DIAMETER_MARGIN)/ 2.0, h = 100, center = True)
    )

  front_hole_a = translate([-HOLE_FRONT_X_SHIFT,0, 5]) (
        cylinder(r = HOLE_RADIUS, h = 100, center = True)
    )
  front_hole_b = translate([-HOLE_FRONT_X_SHIFT,HOLE_FRONT_Y_SHIFT, 5]) (
        cylinder(r = HOLE_RADIUS, h = 100, center = True)
    )

  back_hole_a = translate([HOLE_BACK_X_SHIFT,0, 5]) (
        cylinder(r = HOLE_RADIUS, h = 20, center = True)
    )
  back_hole_b = translate([HOLE_BACK_X_SHIFT,HOLE_BACK_Y_SHIFT, 5]) (
        cylinder(r = HOLE_RADIUS, h = 20, center = True)
    )

  rasp_hole_a = translate([RASP_HOLE_X_SHIFT, -RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )

  rasp_hole_b = translate([RASP_HOLE_X_SHIFT, RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )


  rasp_hole_c = translate([RASP_HOLE_X_SHIFT + 15, -RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )

  rasp_hole_d = translate([RASP_HOLE_X_SHIFT + 15, RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )


  head_mount = base + rear_reinforce + rasp_plate
    
  return head_mount - hole()(front_hole_a + front_hole_b + servo_hole + back_hole_a + back_hole_b + rasp_hole_a + rasp_hole_b + rasp_hole_c + rasp_hole_d)


if __name__ == '__main__':
    a = head_mount()
    scad_render_to_file( a, "robot_head_mount_2.scad", file_header='$fn = %s;' % SEGMENTS)
  



import raspberry_case
from solid import *
from solid.utils import *  # Not required, but the utils module is useful

SEGMENTS = 40


FRONT_WIDTH=56
PLATE_WIDTH=2
FRONT_X_SHIFT=25
FRONT_BACK_SHIFT=15
FRONT_LENGTH=60
RASP_PLATE_HEIGHT=20

SERVO_HEAD_DIAMETER = 26 # 24.5
HOLE_FRONT_X_SHIFT=16.5
HOLE_FRONT_Y_SHIFT=10
HOLE_BACK_X_SHIFT=32.5
HOLE_BACK_Y_SHIFT=10
HOLE_RADIUS=1.5
RASP_HOLE_X_SHIFT=40
RASP_HOLE_Y_SHIFT=15
RASP_HOLE_RADIUS=1.5

MARGIN = 1

def parallelogram(w,h, skew, plate_width):
  return linear_extrude(height = plate_width)(
      polygon(points=[[0,0], [w,0], [w + skew, h], [skew,h], [0,0]], paths=[[0,1,2,3]])
  )

RASP_FIX_PLATE_WIDTH=3

def head_mount():       
  head_mount = union() (
      translate([-FRONT_X_SHIFT,-FRONT_WIDTH / 2,0]) (
        cube([FRONT_LENGTH + 5, FRONT_WIDTH, PLATE_WIDTH])
      ),

       translate([FRONT_BACK_SHIFT, -FRONT_WIDTH / 2, 0]) (
         rotate([90,0,0]) (
            parallelogram(FRONT_LENGTH - 10 - FRONT_X_SHIFT,RASP_PLATE_HEIGHT, RASP_PLATE_HEIGHT, PLATE_WIDTH)
         )
       ),

      translate([FRONT_BACK_SHIFT,0,0]) (
        translate([0, FRONT_WIDTH / 2 - 0.001 + PLATE_WIDTH, 0])  (
          rotate([90,0,0]) (
             parallelogram(FRONT_LENGTH - 10 - FRONT_X_SHIFT,RASP_PLATE_HEIGHT, RASP_PLATE_HEIGHT, PLATE_WIDTH)
          )
        )
      ),

      translate([FRONT_BACK_SHIFT + 25, -FRONT_WIDTH / 2, 0]) (
        rotate([-90,0,0]) (
          parallelogram(FRONT_LENGTH - 40 - FRONT_X_SHIFT,-5,5, FRONT_WIDTH)
        )
      ),

      translate([FRONT_BACK_SHIFT, -FRONT_WIDTH / 2, 0]) (
        rotate([-90,0,0]) (
          parallelogram(FRONT_LENGTH - 10 - FRONT_X_SHIFT,-5,5, 5)
        )
      ),

      translate([FRONT_BACK_SHIFT, FRONT_WIDTH / 2 - 5, 0]) (
        rotate([-90,0,0]) (
          parallelogram(FRONT_LENGTH - 10 - FRONT_X_SHIFT,-5,5, 5)
        )
      ),

      translate([RASP_PLATE_HEIGHT - RASP_FIX_PLATE_WIDTH + FRONT_BACK_SHIFT, -FRONT_WIDTH / 2, RASP_PLATE_HEIGHT - RASP_FIX_PLATE_WIDTH]) (
        rotate([-90,0,0]) (
          parallelogram(FRONT_LENGTH - 10 - FRONT_X_SHIFT,-RASP_FIX_PLATE_WIDTH,RASP_FIX_PLATE_WIDTH, 10)
        )
      ),

      translate([RASP_PLATE_HEIGHT - RASP_FIX_PLATE_WIDTH + FRONT_BACK_SHIFT, FRONT_WIDTH / 2 - 10, RASP_PLATE_HEIGHT - RASP_FIX_PLATE_WIDTH]) (
        rotate([-90,0,0]) (
          parallelogram(FRONT_LENGTH - 10 - FRONT_X_SHIFT,-RASP_FIX_PLATE_WIDTH,RASP_FIX_PLATE_WIDTH, 10)
        )
      )
  )

  servo_hole = translate([0,0, 5]) (
    cylinder(r = SERVO_HEAD_DIAMETER / 2.0 + MARGIN / 2, h = 100, center = True)
    )

  front_hole_a = translate([-HOLE_FRONT_X_SHIFT,0, 5]) (
        cylinder(r = HOLE_RADIUS, h = 100, center = True)
    )
  front_hole_b = translate([-HOLE_FRONT_X_SHIFT,HOLE_FRONT_Y_SHIFT, 5]) (
        cylinder(r = HOLE_RADIUS, h = 100, center = True)
    )

  back_hole_a = translate([HOLE_BACK_X_SHIFT,0, 5]) (
        cylinder(r = HOLE_RADIUS, h = 20, center = True)
    )
  back_hole_b = translate([HOLE_BACK_X_SHIFT,HOLE_BACK_Y_SHIFT, 5]) (
        cylinder(r = HOLE_RADIUS, h = 20, center = True)
    )

  rasp_hole_a = translate([RASP_HOLE_X_SHIFT, -RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )

  rasp_hole_b = translate([RASP_HOLE_X_SHIFT, RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )


  rasp_hole_c = translate([RASP_HOLE_X_SHIFT + 15, -RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )

  rasp_hole_d = translate([RASP_HOLE_X_SHIFT + 15, RASP_HOLE_Y_SHIFT, 55]) (
        cylinder(r = RASP_HOLE_RADIUS, h = 80, center = True)
    )


  
  return head_mount - hole()(front_hole_a + front_hole_b + servo_hole + back_hole_a + back_hole_b + rasp_hole_a + rasp_hole_b + rasp_hole_c + rasp_hole_d)


if __name__ == '__main__':
    a = head_mount()
    scad_render_to_file( a, "robot_head_mount.scad", file_header='$fn = %s;' % SEGMENTS)
  



from solid import *
from solid.utils import *  # Not required, but the utils module is useful

SEGMENTS = 20

RASP_TOTAL_X=85.5
RASP_TOTAL_Y=57
RASP_TOTAL_Z=20

AIR_HOLE_NUMBER=6
AIR_HOLE_DIAMETER=2

BASE_PLATE_ENTRETOISE_RADIUS=3
RASP_HOLE_RADIUS=2.9 / 2.0
BASE_PLATE_HOLE_RADIUS=RASP_HOLE_RADIUS
ENTRETOISE_HEIGHT = 7
BASE_PLATE_ENTRETOISES = [[25.5,   18, ENTRETOISE_HEIGHT / 2.0],
                          [  25.5, 43.5, ENTRETOISE_HEIGHT / 2.0],
                          [  79, 43.5, ENTRETOISE_HEIGHT / 2.0],
                          [  77, 10, ENTRETOISE_HEIGHT / 2.0],
                          ]


CALE_HEIGHT=3
CALE_WIDTH=3
CALE_H_LENGTH=10
CALE_V_LENGTH=CALE_H_LENGTH + CALE_WIDTH
H_CALES = [[0, -CALE_WIDTH,0],
           [RASP_TOTAL_X - CALE_H_LENGTH, -CALE_WIDTH,0],
           [RASP_TOTAL_X - CALE_H_LENGTH, RASP_TOTAL_Y,0],
           [0, RASP_TOTAL_Y,0],
          ]

V_CALES = [[-CALE_WIDTH , RASP_TOTAL_Y - CALE_V_LENGTH + CALE_WIDTH,0],
           [RASP_TOTAL_X, RASP_TOTAL_Y - CALE_V_LENGTH + CALE_WIDTH,0],
          ]

HDMI_PORT_X_SHIFT = 45;
USB_PORT_Y_SHIFT = 30;
HDMI_HEIGHT = 15
USB_HEIGHT = 15

def cable_output():
   hdmi = translate([HDMI_PORT_X_SHIFT, -70, ENTRETOISE_HEIGHT + HDMI_HEIGHT / 2]) (
      cube([25,150, HDMI_HEIGHT], center = True)
   )
   usb = translate([170, USB_PORT_Y_SHIFT, ENTRETOISE_HEIGHT + USB_HEIGHT / 2])(
      cube([150,25, USB_HEIGHT], center = True)
   )
   return hdmi + usb


def entretoise (r_outer, r_inner, h, center = False):
  return cylinder(r=r_outer, h=h, center = center) - cylinder(r=r_inner, h=h * 2, center = center)

def air_holes():
  return translate([40,30, 0])(
      [
        rotate(i  * 360 / AIR_HOLE_NUMBER, [0, 0, 1])
        (
              translate([0, 10, 0])
              (
                  cylinder(r=AIR_HOLE_DIAMETER, h=10,  center = True)
              )
        )
        for i in range(6)
      ]
    )

def h_cale(i):
  return translate(i) (
    cube([CALE_H_LENGTH, CALE_WIDTH, ENTRETOISE_HEIGHT + CALE_HEIGHT], center = False)
  )


def v_cale(i):
  return translate(i) (
    cube([CALE_WIDTH, CALE_V_LENGTH, ENTRETOISE_HEIGHT + CALE_HEIGHT], center = False)
  )

def raspberry_case():
  holes = air_holes() + cable_output()
  entretoises = [translate(i)
                 (entretoise(BASE_PLATE_ENTRETOISE_RADIUS, BASE_PLATE_HOLE_RADIUS, h = ENTRETOISE_HEIGHT, center=True))
                 for i in BASE_PLATE_ENTRETOISES]

  h_cales = [h_cale(i) for i in H_CALES ]
  v_cales = [v_cale(i) for i in V_CALES ]

  return union()(entretoises + h_cales + v_cales) - hole()(holes)

if __name__ == '__main__':
    CASE_X_SIZE = 130
    case_width = 2
    outer_case  = cube([CASE_X_SIZE, 100, 40]) - translate([case_width,case_width,case_width])(cube([CASE_X_SIZE - case_width * 2, 100 - case_width * 2, 40]))
#    outer_case = minkowski()(outer_case, cylinder(r = 1, h = 1))
    a = outer_case + translate([20, 20])(rotate(0)(raspberry_case()))
    scad_render_to_file( a, "raspberry_py_case.scad", file_header='$fn = %s;' % SEGMENTS, include_orig_code=True)



#!/usr/bin/env python
from setuptools import setup, find_packages
import sys, os

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
NEWS = open(os.path.join(here, 'NEWS.txt')).read()


version = '0.1'

install_requires = [
    # List your project dependencies here.
    # For more details, see:
    # http://packages.python.org/distribute/setuptools.html#declaring-dependencies
]


setup(name='madlag3dware',
    version=version,
    description="solidpython/openscad parametric designs (raspberry pi case elements etc)",
    long_description=README + '\n\n' + NEWS,
    classifiers=[
      # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    ],
    keywords='',
    author='Francois Lagunas',
    author_email='francois.lagunas@gmail.com',
    url='',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    entry_points={
        'console_scripts':
            ['madlag3dware=madlag3dware:main']
    }
)
